# -*- coding: utf-8 -*-
# Copyright © 2021 Contrast Security, Inc.
# See https://www.contrastsecurity.com/enduser-terms-0317a for more details.

DEFAULT_LOG_PATH = "contrast-agent.log"
DEFAULT_LOG_LEVEL = "INFO"
DEFAULT_PROGNAME = "Contrast Agent"
LOGGER_NAME = "contrast"

# Trace level for stdlib and structlog
TRACE_LEVEL = 5
